@@ -1,4 +1,4 @@
-from typing import Literal, Optional, TypeVar
+from typing import Literal, TypeVar
 
 from attrs import frozen
 
@@ -12,11 +12,11 @@ SameSite = Literal["strict", "lax", "none"]
 
 @frozen
 class CookieSettings:
-    max_age: Optional[int] = None  # Seconds
+    max_age: int | None = None  # Seconds
     http_only: bool = True
     secure: bool = True
-    path: Optional[str] = None
-    domain: Optional[str] = None
+    path: str | None = None
+    domain: str | None = None
     same_site: SameSite = "lax"
 
 
@@ -42,13 +42,19 @@ def _make_delete_cookie_header(name: str) -> dict:
     return {f"__cookie_{name}": val}
 
 
+#: A cookie dependency.
 class Cookie(str):
     ...
 
 
 def set_cookie(
-    name: str, value: Optional[str], settings: CookieSettings = CookieSettings()
+    name: str, value: str | None, settings: CookieSettings = CookieSettings()
 ) -> Headers:
+    """
+    Produce headers that should be returned as part of a response to set the cookie.
+
+    :param value: When `None`, the cookie will be deleted.
+    """
     return (
         _make_cookie_header(name, value, settings)
         if value is not None
