@@ -1,9 +1,10 @@
-from typing import Annotated, Callable, Optional, TypeVar
+from collections.abc import Callable
+from typing import Annotated, TypeVar
 
 from itsdangerous import BadSignature, URLSafeTimedSerializer
 
 from .. import Cookie
-from ..base import App
+from ..base import App, AsyncApp
 from ..cookies import CookieSettings, set_cookie
 from ..status import Headers
 
@@ -20,7 +21,7 @@ class Session(dict[str, str]):
 
 
 def configure_secure_sessions(
-    app: App,
+    app: App | AsyncApp,
     secret_key: str,
     cookie_name: str = "session",
     salt: str = "cookie-session",
@@ -45,7 +46,7 @@ def configure_secure_sessions(
         )
 
     def get_session(
-        session: Annotated[Optional[str], Cookie(cookie_name)] = None
+        session: Annotated[str | None, Cookie(cookie_name)] = None
     ) -> Session:
         if session is None:
             res = Session()
@@ -60,6 +61,6 @@ def configure_secure_sessions(
         res._serialize = _serialize
         return res
 
-    app.base_incant.register_hook(
+    app.incant.register_hook(
         lambda p: p.name == "session" and p.annotation is Session, get_session
     )
