@@ -1,16 +1,16 @@
 """Redis backends for sessions."""
-
 from datetime import timedelta
 from json import dumps, loads
 from secrets import token_hex
 from time import time
-from typing import TYPE_CHECKING, Annotated, Optional, TypeVar
+from typing import TYPE_CHECKING, Annotated, TypeVar
 
 from attrs import frozen
 
 from .. import Cookie, Headers
-from ..base import App
+from ..base import AsyncApp, OpenAPISecuritySpec
 from ..cookies import CookieSettings, set_cookie
+from ..openapi import ApiKeySecurityScheme
 
 if TYPE_CHECKING:
     from aioredis import Redis
@@ -28,7 +28,7 @@ class AsyncSession(dict[str, str]):
     _ttl: int
     _key_prefix: str
 
-    async def update_session(self, *, namespace: Optional[str] = None) -> Headers:
+    async def update_session(self, *, namespace: str | None = None) -> Headers:
         namespace = namespace or self._namespace
         if namespace is None:
             raise Exception("The namespace must be set for new sessions.")
@@ -83,7 +83,7 @@ class AsyncRedisSessionStore:
 
 
 def configure_async_sessions(
-    app: App,
+    app: AsyncApp,
     aioredis: "Redis",
     max_age: timedelta = timedelta(days=14),
     cookie_name: str = "session_id",
@@ -91,10 +91,41 @@ def configure_async_sessions(
     redis_key_prefix: str = "",
     session_arg_param_name: str = "session",
 ) -> AsyncRedisSessionStore:
+    """
+    Configure an instance of async sessions for an app.
+
+    A session ID will be generated using Python's `secrets.token_hex` and stored in a
+    cookie.
+
+    Once configured, handlers may declare a parameter of name _session_arg_param_name
+    (defaults to `session`) and type `AsyncSession`. AsyncSessions are mappings of
+    strings to strings, and can be used to store data using the
+    `AsyncSession.update_session()` and `AsyncSession.clear_session()` coroutines.
+
+    If the cookie is missing or the session data has expired, a new empty session will
+    be transparently created.
+
+    Sessions have optional namespaces. Namespaces are useful for logically grouping
+    sessions, for example by user ID, so that multiple sessions can be cleared at once.
+
+    Fresh sessions start with no namespace set. To set a namespace, pass it to
+    `AsyncSession.update_session()`.
+
+    An `AsyncRedisSessionStore` is produced at configuration time and can be used to
+    clean up namespaces even outside the context of a request.
+
+    :param max_age: The maximum age of a session. When this expires, the session is
+        cleaned up from Redis.
+    :param cookie_name: The name of the cookie to use for the session id.
+    :param cookie_settings: The settings for the cookie.
+    :param redis_key_prefix: The prefix to use for redis keys.
+    :param session_arg_param_name: The name of the handler parameter that will be
+        available for dependency injection.
+    """
     ttl = int(max_age.total_seconds())
 
     async def session_factory(
-        cookie: Annotated[Optional[str], Cookie(cookie_name)] = None
+        cookie: Annotated[str | None, Cookie(cookie_name)] = None
     ) -> AsyncSession:
         if cookie is not None:
             namespace, id = cookie.split(":")
@@ -123,11 +154,15 @@ def configure_async_sessions(
         res._key_prefix = redis_key_prefix
         return res
 
-    app.base_incant.register_hook(
+    app.incant.register_hook(
         lambda p: p.name == session_arg_param_name and p.annotation is AsyncSession,
         session_factory,
     )
 
+    app._openapi_security.append(
+        OpenAPISecuritySpec(ApiKeySecurityScheme(cookie_name, "cookie"))
+    )
+
     return AsyncRedisSessionStore(
         aioredis, redis_key_prefix, cookie_name, cookie_settings
     )
