@@ -1,26 +1,47 @@
+"""Status code classes for return values."""
 from functools import cache
-from types import MappingProxyType
-from typing import Generic, Literal, Mapping, TypeAlias, TypeVar
+from typing import Generic, Literal, TypeAlias, TypeVar
 
-from attrs import define, frozen
+from attrs import Factory, define, frozen
+
+__all__ = [
+    "Ok",
+    "Created",
+    "NoContent",
+    "Found",
+    "SeeOther",
+    "BadRequest",
+    "Forbidden",
+    "NotFound",
+    "InternalServerError",
+    "BaseResponse",
+    "R",
+]
 
 R = TypeVar("R")
 S = TypeVar("S")
 
 
-Headers: TypeAlias = Mapping[str, str]
+Headers: TypeAlias = dict[str, str]
 
 
 @define(order=False)
 class BaseResponse(Generic[S, R]):
     ret: R
-    headers: Headers = MappingProxyType({})
+    headers: Headers = Factory(dict)
 
     @classmethod
     def status_code(cls) -> int:
         return cls.__orig_bases__[0].__args__[0].__args__[0]  # type: ignore
 
 
+@define
+class ResponseException(Exception):
+    """An exception that is converted into an HTTP response."""
+
+    response: BaseResponse
+
+
 @cache
 def get_status_code(resp: type[BaseResponse]) -> int:
     return resp.status_code()
@@ -68,3 +89,8 @@ class Forbidden(BaseResponse[Literal[403], R]):
 @define
 class NotFound(BaseResponse[Literal[404], R]):
     pass
+
+
+@define
+class InternalServerError(BaseResponse[Literal[500], R]):
+    pass
